'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _margins = require('./util/margins');

var _margins2 = _interopRequireDefault(_margins);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * Generic box with visual styling
 */

var Block = function Block(_ref, _ref2) {
  var color = _ref.color;
  var backgroundColor = _ref.backgroundColor;
  var borderColor = _ref.borderColor;
  var border = _ref.border;
  var borderTop = _ref.borderTop;
  var borderRight = _ref.borderRight;
  var borderBottom = _ref.borderBottom;
  var borderLeft = _ref.borderLeft;
  var style = _ref.style;

  var props = _objectWithoutProperties(_ref, ['color', 'backgroundColor', 'borderColor', 'border', 'borderTop', 'borderRight', 'borderBottom', 'borderLeft', 'style']);

  var rebass = _ref2.rebass;

  var config = _extends({}, _theme2.default, rebass);
  var scale = config.scale;
  var colors = config.colors;

  var customStyle = rebass && rebass.Block || {};
  var customColor = colors[color] || color;

  color = colors[color] || color || 'inherit';
  backgroundColor = colors[backgroundColor] || backgroundColor || null;
  borderColor = colors[borderColor] || borderColor || colors.primary;

  var sx = _extends({
    boxSizing: 'border-box',
    padding: scale[2],
    marginBottom: scale[2],
    borderStyle: border ? 'solid' : 'none',
    borderTopStyle: borderTop ? 'solid' : null,
    borderRightStyle: borderRight ? 'solid' : null,
    borderBottomStyle: borderBottom ? 'solid' : null,
    borderLeftStyle: borderLeft ? 'solid' : null,
    borderWidth: 4,
    borderColor: borderColor,
    color: color,
    backgroundColor: backgroundColor
  }, customStyle, (0, _margins2.default)(props, scale), style);

  return _react2.default.createElement('div', _extends({}, props, {
    className: 'Block',
    style: sx }));
};

Block.propTypes = {
  /** Text color - can either be a key from the theme colors object or any color value */
  color: _react2.default.PropTypes.string,
  /** Background color - can either be a key from the theme colors object or any color value */
  backgroundColor: _react2.default.PropTypes.string,
  /** Border color - can either be a key from the theme colors object or any color value */
  borderColor: _react2.default.PropTypes.string,
  /** Adds a border */
  border: _react2.default.PropTypes.bool,
  /** Adds a border to the top side */
  borderTop: _react2.default.PropTypes.bool,
  /** Adds a border to the right side */
  borderRight: _react2.default.PropTypes.bool,
  /** Adds a border to the bottom side */
  borderBottom: _react2.default.PropTypes.bool,
  /** Adds a border to the left side */
  borderLeft: _react2.default.PropTypes.bool,
  /** Applies margin based on the theme spacing scale */
  m: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4]),
  /** Applies margin top based on the theme spacing scale */
  mt: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4]),
  /** Applies margin right based on the theme spacing scale */
  mr: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4]),
  /** Applies margin bottom based on the theme spacing scale */
  mb: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4]),
  /** Applies margin left based on the theme spacing scale */
  ml: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4]),
  /** Applies margin left and right based on the theme spacing scale */
  mx: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4]),
  /** Applies margin top and bottom based on the theme spacing scale */
  my: _react2.default.PropTypes.oneOf([0, 1, 2, 3, 4])
};

Block.contextTypes = {
  rebass: _react2.default.PropTypes.object
};

exports.default = Block;