'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * A general purpose button element with customizable colors
 */

var Button = function Button(_ref, _ref2) {
  var href = _ref.href;
  var big = _ref.big;
  var rounded = _ref.rounded;
  var color = _ref.color;
  var backgroundColor = _ref.backgroundColor;
  var children = _ref.children;
  var style = _ref.style;
  var className = _ref.className;

  var props = _objectWithoutProperties(_ref, ['href', 'big', 'rounded', 'color', 'backgroundColor', 'children', 'style', 'className']);

  var rebass = _ref2.rebass;


  var config = _extends({}, _theme2.default, rebass);
  var customStyle = rebass ? rebass.Button : {};
  var fontSizes = config.fontSizes;
  var bold = config.bold;
  var scale = config.scale;
  var colors = config.colors;
  var borderRadius = config.borderRadius;


  var Component = href ? 'a' : 'button';

  var radii = {
    top: borderRadius + 'px ' + borderRadius + 'px 0 0',
    right: '0 ' + borderRadius + 'px ' + borderRadius + 'px 0',
    bottom: '0 0 ' + borderRadius + 'px ' + borderRadius + 'px',
    left: borderRadius + 'px 0 0 ' + borderRadius + 'px'
  };

  color = colors[color] || color || colors.white;
  backgroundColor = colors[backgroundColor] || backgroundColor || colors.primary;

  var sx = _extends({
    fontFamily: 'inherit',
    fontSize: fontSizes[5],
    fontWeight: bold,
    lineHeight: scale[2] + 'px',
    textDecoration: 'none',
    display: 'inline-block',
    margin: 0,
    padding: big ? scale[2] : scale[1] + 'px ' + scale[2] + 'px',
    cursor: 'pointer',
    border: 0,
    borderRadius: rounded ? radii[rounded] || borderRadius : 0,
    color: color,
    backgroundColor: backgroundColor
  }, customStyle, style);

  return _react2.default.createElement(
    Component,
    _extends({}, props, {
      href: href,
      className: 'Button',
      style: sx }),
    children
  );
};

Button.propTypes = {
  /** Pass an href prop to make the Button an <a> tag instead of a <button> */
  href: _react2.default.PropTypes.string,
  /** Button color - can either be a key from the theme colors object or any color value */
  color: _react2.default.PropTypes.string,
  /** Background color - can either be a key from the theme colors object or any color value */
  backgroundColor: _react2.default.PropTypes.string,
  /** Controls the border radius for creating button groups */
  rounded: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.bool, _react2.default.PropTypes.oneOf(['top', 'right', 'bottom', 'left'])]),
  /** Creates a larger button */
  big: _react2.default.PropTypes.bool
};

Button.defaultProps = {
  rounded: true
};

Button.contextTypes = {
  rebass: _react2.default.PropTypes.object
};

exports.default = Button;