'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Label = require('./Label');

var _Label2 = _interopRequireDefault(_Label);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _margins = require('./util/margins');

var _margins2 = _interopRequireDefault(_margins);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * Input element with label
 */

var Input = function Input(_ref, _ref2) {
  var label = _ref.label;
  var name = _ref.name;
  var type = _ref.type;
  var hideLabel = _ref.hideLabel;
  var rounded = _ref.rounded;
  var children = _ref.children;
  var style = _ref.style;

  var props = _objectWithoutProperties(_ref, ['label', 'name', 'type', 'hideLabel', 'rounded', 'children', 'style']);

  var rebass = _ref2.rebass;

  var config = _extends({}, _theme2.default, rebass);
  var customStyle = rebass ? rebass.Input : {};
  var scale = config.scale;
  var borderRadius = config.borderRadius;
  var borderColor = config.borderColor;


  var otherStyle = _extends({}, customStyle, style);

  var radii = {
    top: borderRadius + 'px ' + borderRadius + 'px 0 0',
    right: '0 ' + borderRadius + 'px ' + borderRadius + 'px 0',
    bottom: '0 0 ' + borderRadius + 'px ' + borderRadius + 'px',
    left: borderRadius + 'px 0 0 ' + borderRadius + 'px'
  };

  var sx = {
    root: _extends({
      marginBottom: scale[2]
    }, (0, _margins2.default)(props, scale)),
    input: _extends({
      fontFamily: 'inherit',
      fontSize: 'inherit',
      boxSizing: 'border-box',
      display: 'block',
      width: '100%',
      height: scale[3],
      paddingLeft: scale[1],
      paddingRight: scale[1],
      margin: 0,
      color: 'inherit',
      backgroundColor: 'rgba(255, 255, 255, .25)',
      borderRadius: rounded ? radii[rounded] || borderRadius : 0,
      borderWidth: 1,
      borderStyle: 'solid',
      borderColor: borderColor
    }, otherStyle)
  };

  return _react2.default.createElement(
    'div',
    { className: 'Input',
      style: sx.root },
    _react2.default.createElement(_Label2.default, {
      htmlFor: name,
      hide: hideLabel,
      children: label }),
    _react2.default.createElement('input', _extends({}, props, {
      type: type,
      name: name,
      style: sx.input }))
  );
};

Input.propTypes = {
  /** Label for form element */
  label: _react2.default.PropTypes.string.isRequired,
  /** Name attribute for form element */
  name: _react2.default.PropTypes.string.isRequired,
  /** Form element type */
  type: _react2.default.PropTypes.string,
  /** Hides the form element label */
  hideLabel: _react2.default.PropTypes.bool,
  /** Controls the border radius for creating grouped elements */
  rounded: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.bool, _react2.default.PropTypes.oneOf(['top', 'right', 'bottom', 'left'])])
};

Input.defaultProps = {
  type: 'text',
  rounded: true
};

Input.contextTypes = {
  rebass: _react2.default.PropTypes.object
};

exports.default = Input;